package com.ruoyi.pt.controller;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.pt.service.CasesImportService;
import com.ruoyi.pt.service.RemoteCallsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;

/**
 * 远程推送算法平台数据
 *
 * @author wu
 * @since 2023/12/15 13:41
 */
@Api(tags = "远程推送算法平台数据⼊")
@RestController
@RequestMapping("/remoteCall")
public class RemoteCallsController extends BaseController {

    @Resource
    private RemoteCallsService remoteCallsService;

    @Resource
    private CasesImportService casesImportService;

    /**
     * 获取公共accessToken
     *
     * @return 响应类
     */
    @ApiOperation(value = "获取公共accessToken")
    @GetMapping("/getAccessToken")
    public AjaxResult getAccessToken() {

        return success(remoteCallsService.getAccessToken());
    }

    /**
     * 事件进度推送接口
     *
     * @param allPush 是否全推送 1为推送所有 null为推送当天
     * @return 响应类
     */
    @ApiOperation(value = "事件进度推送接口")
    @PostMapping("/imports")
    public AjaxResult imports(@RequestBody Integer allPush) {
        remoteCallsService.imports(allPush);
        return success();
    }

    /**
     * 事件进度临时推送接口
     *
     * @return 响应类
     */
    @ApiOperation(value = "事件进度临时推送接口")
    @PostMapping("/temporaryImports")
    public AjaxResult temporaryImports( ) {
        remoteCallsService.temporaryImports();
        return success();
    }

    /**
     * 获取社会治理中心增量事件保存到events_import表
     *
     * @return 响应类
     */
    @ApiOperation(value = "获取社会治理中心增量事件保存到events_import表")
    @GetMapping("/getEventDate")
    public AjaxResult getEventDate() {
        remoteCallsService.getEventDate();
        return success();
    }

    @ApiOperation(value = "更新算法数据并推送")
    @GetMapping("/pushDate")
    public AjaxResult pushData() {
        // 获取社会治理中心增量事件保存到events_import表
        remoteCallsService.getEventDate();
        // 获取昨天的数据
        LocalDate localDate = LocalDate.now();
        LocalDate yesterday = localDate.minusDays(1);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String yesterdayStr = yesterday.format(formatter);
        // 紧急事件接口
        remoteCallsService.urgentAlgorithm(yesterdayStr);
        // 群体事件接口
        remoteCallsService.groupAlgorithm();
        // 同人事件接口
        remoteCallsService.onepersonAlgorithm();
        // 推送
        remoteCallsService.imports(null);
        return success();
    }

    /**
     * 算法处理所有数据
     *
     * @return 响应类
     */
    @ApiOperation(value = "算法处理所有数据")
    @GetMapping("/urgentAlgorithm")
    public AjaxResult urgentAlgorithm() {
        List<String> list = casesImportService.findDate();
        list.forEach(x -> remoteCallsService.urgentAlgorithm(x));
        return success();
    }
}
