package com.ruoyi.pt.quartz;

import com.ruoyi.pt.service.RemoteCallsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;

/**
 * 推送平台数据定时任务
 *
 * @author wu
 * @since 2023/12/26 16:19
 */
@Configuration
@EnableScheduling
public class PushQuartz {

    public static final Logger log = LoggerFactory.getLogger(PushQuartz.class);
    @Resource
    private RemoteCallsService remoteCallsService;

    @Scheduled(cron = "0 0 1 * * ? ")
    public synchronized void pushData() {
        log.info("==============开始定时任务" + LocalDateTime.now() + "============");
        // 获取社会治理中心增量事件保存到events_import表
        remoteCallsService.getEventDate();
        // 获取昨天的数据
        LocalDate localDate = LocalDate.now();
        LocalDate yesterday = localDate.minusDays(1);
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyy-MM-dd");
        String yesterdayStr = yesterday.format(formatter);
        log.info("==============推送紧急事件接口" + LocalDateTime.now() + "============");
        // 紧急事件接口
        remoteCallsService.urgentAlgorithm(yesterdayStr);
        // 群体事件接口
        log.info("==============推送群体事件接口" + LocalDateTime.now() + "============");
        remoteCallsService.groupAlgorithm();
        // 同人事件接口
        log.info("==============推送同人事件接口" + LocalDateTime.now() + "============");
        remoteCallsService.onepersonAlgorithm();
        // 推送
//        log.info("==============推送到预警平台接口" + LocalDateTime.now() + "============");
//        remoteCallsService.imports(null);
    }
}
